==> environment-1.2.20-sources.jar: com/chutneytesting/environment/infra/TargetJsonDeserializer.java <==
package com.chutneytesting.environment.infra;

import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonDeserializer;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.Optional;

public class TargetJsonDeserializer extends JsonDeserializer<JsonTarget> {

    private static final ObjectMapper mapper = new ObjectMapper();

    @Override
    public JsonTarget deserialize(JsonParser jsonParser, DeserializationContext deserializationContext) throws IOException {
        JsonNode targetNode = jsonParser.getCodec().readTree(jsonParser);

        String name = null;
        if (targetNode.hasNonNull("name")) {
            name = targetNode.get("name").textValue();
        }
        String url = null;
        if (targetNode.hasNonNull("url")) {
            url = targetNode.get("url").textValue();
        }
        Map<String, String> properties = new HashMap<>();
        if (targetNode.hasNonNull("properties")) {
           properties = mapper.readValue(targetNode.get("properties").toString(), new TypeReference<Map<String, ? extends String>>() {});
        }
        JsonTarget.JsonSecurityInfo securityInfo = null;
        if (targetNode.hasNonNull("security")) {
            JsonNode security = targetNode.get("security");
            String trustStore = null;
            if (security.hasNonNull("trustStore")) {
                trustStore = security.get("trustStore").textValue();
            }
            String trustStorePassword = null;
            if (security.hasNonNull("trustStorePassword")) {
                trustStorePassword = security.get("trustStorePassword").textValue();
            }
            String keyStore = null;
            if (security.hasNonNull("keyStore")) {
                keyStore = security.get("keyStore").textValue();
            }
            String keyStorePassword = null;
            if (security.hasNonNull("keyStorePassword")) {
                keyStorePassword = security.get("keyStorePassword").textValue();
            }
            String privateKey = null;
            if (security.hasNonNull("privateKey")) {
                privateKey = security.get("privateKey").textValue();
            }
            JsonTarget.JsonCredential credential = null;

            if (security.hasNonNull("credential")) {
                JsonNode jsonCredential = security.get("credential");
                if (jsonCredential.hasNonNull("username")) {
                    String username = jsonCredential.get("username").textValue();
                    String password = Optional.ofNullable(jsonCredential.get("password")).map(JsonNode::textValue).orElse("");
                    credential = new JsonTarget.JsonCredential(username, password);
                }
            }
            securityInfo = new JsonTarget.JsonSecurityInfo(credential, trustStore,trustStorePassword, keyStore, keyStorePassword, privateKey );
        }
        return new JsonTarget(url, properties, securityInfo, name);
    }
}

==> environment-1.6.0-sources.jar: com/chutneytesting/environment/infra/TargetJsonDeserializer.java <==
package com.chutneytesting.environment.infra;

import static java.util.Optional.ofNullable;

import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonDeserializer;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

public class TargetJsonDeserializer extends JsonDeserializer<JsonTarget> {

    private static final ObjectMapper mapper = new ObjectMapper();

    @Override
    public JsonTarget deserialize(JsonParser jsonParser, DeserializationContext deserializationContext) throws IOException {
        JsonNode targetNode = jsonParser.getCodec().readTree(jsonParser);

        String name = null;
        if (targetNode.hasNonNull("name")) {
            name = targetNode.get("name").textValue();
        }

        String url = null;
        if (targetNode.hasNonNull("url")) {
            url = targetNode.get("url").textValue();
        }

        Map<String, String> properties = new HashMap<>();
        if (targetNode.hasNonNull("properties")) {
            properties = mapper.readValue(targetNode.get("properties").toString(), new TypeReference<>() {
            });
        }

        if (targetNode.hasNonNull("security")) {
            JsonNode security = targetNode.get("security");
            if (security.hasNonNull("trustStore")) {
                properties.put("trustStore", security.get("trustStore").textValue());
            }
            if (security.hasNonNull("trustStorePassword")) {
                properties.put("trustStorePassword", security.get("trustStorePassword").textValue());
            }
            if (security.hasNonNull("keyStore")) {
                properties.put("keyStore", security.get("keyStore").textValue());
            }
            if (security.hasNonNull("keyStorePassword")) {
                properties.put("keyStorePassword", security.get("keyStorePassword").textValue());
            }
            if (security.hasNonNull("keyPassword")) {
                properties.put("keyPassword", security.get("keyPassword").textValue());
            }
            if (security.hasNonNull("privateKey")) {
                properties.put("privateKey", security.get("privateKey").textValue());
            }
            if (security.hasNonNull("credential")) {
                JsonNode jsonCredential = security.get("credential");
                if (jsonCredential.hasNonNull("username")) {
                    properties.put("username", jsonCredential.get("username").textValue());
                    properties.put("password", ofNullable(jsonCredential.get("password")).map(JsonNode::textValue).orElse(""));
                }
            }
        }

        return new JsonTarget(name, url, properties);
    }
}
